pychemia.population package
===========================

.. automodule:: pychemia.population
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    pychemia.population.tests

Submodules
----------

pychemia.population.ljcluster module
------------------------------------

.. automodule:: pychemia.population.ljcluster
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.population.noncollinearmagmoms module
----------------------------------------------

.. automodule:: pychemia.population.noncollinearmagmoms
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.population.orbitaldftu module
--------------------------------------

.. automodule:: pychemia.population.orbitaldftu
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.population.realfunction module
---------------------------------------

.. automodule:: pychemia.population.realfunction
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.population.relaxstructures module
------------------------------------------

.. automodule:: pychemia.population.relaxstructures
    :members:
    :undoc-members:
    :show-inheritance:


